/**
 * @file
 * Vue app for cart.
 */

(function () {
  "use strict";

  Vue.component("cart-field", {
    props: {
      pid: 0,
      uid: 0,
      variations: false,
      attributes: false,
      settings: false,
    },
    data() {
      return {
        inCart: false,
        ready: false,
        loading: false,
        variationId: false,
        oldPrice: false,
        price: false,
        attributeCount: false,
        activeIds: [],
        enableIds: [],
        quantity: 1,
      };
    },
    computed: {
      cart() {
        return this.$store.state.cart;
      },
      availability() {
        if (!this.settings.checkstore) {
          return 1;
        }
        let enb = false;
        this.variations.forEach((v) => {
          if (v.stock != 0) {
            enb = true;
          }
        });
        return enb;
      }
    },
    methods: {
      readQuantity(e, item) {
        let quantity = e.target.innerText;
        quantity = parseInt(quantity.replaceAll(" ", ""));
        if (quantity > 999) {
          quantity = 999;
        } else if (quantity < 1) {
          quantity = 1;
        }
        this.changeQuantity(item.id, quantity, item.qstep);
      },
      changeQuantity(vid, quantity, step) {
        this.quantity = !quantity || quantity < step ? step : quantity;
        if (this.settings.checkstore) {
          this.variations.forEach((v) => {
            if (v.variation_id == vid) {
              quantity = v.stock;
            }
          });
          if (this.quantity > quantity) {
            this.quantity = quantity;
          }
        }
        this.inCart = false;
        // let stock = this.$store.state.cart.items[vid].stock;
        // if (quantity <= stock || stock == 0) {
        //   axios
        //     .post("/cart/set-product-quantity", {
        //       vid: vid,
        //       quantity: quantity,
        //     })
        //     .then((response) => {
        //       this.$store.commit("updateCart", response.data);
        //     });
        // }
      },
      numberFormat(number, step, decimals = 2, dec_point = ".", thousands_sep = " ") {
        let s_number =
          Math.abs(parseInt((number = (+number || 0).toFixed(decimals)))) + "";
        let len = s_number.length;
        let tchunk = len > 3 ? len % 3 : 0;
        let ch_first = tchunk ? s_number.substr(0, tchunk) + thousands_sep : "";
        let ch_rest = s_number
          .substr(tchunk)
          .replace(/(\d\d\d)(?=\d)/g, "$1" + thousands_sep);
        let ch_last = decimals
          ? dec_point + (Math.abs(number) - s_number).toFixed(decimals).slice(2)
          : "";
        if (step == 1) {
          ch_last = '';
        }
        return ch_first + ch_rest + ch_last;
      },
      addToCart(variation_id) {
        if (this.loading || !this.variationId) {
          return false;
        }
        this.loading = true;
        axios.post("/cart/add-item", { vid: variation_id, qty: this.quantity }).then(
          (response) => {
            this.inCart = true;
            this.loading = false;
            this.$store.commit("updateCart", response.data);
          },
        );
      },
      // choiceOfAttribute
      selectVariation(id, name) {
        this.inCart = false;
        this.variationId = 0;
        var xvar = [];
        if (this.settings.masterarray.includes(id)) {
          this.$store.commit("updateColor", id);
          this.enableIds = [];
          this.activeIds = [];
          this.activeIds.push(id);
        }
        else {
          if (!this.activeIds.includes(id)) {
            for (var attr in this.attributes) {
              let needclear = false;
              this.attributes[attr].forEach((v) => {
                if (id == v.id) {
                  needclear = true;
                }
              });
              if (needclear) {
                this.attributes[attr].forEach((v) => {
                  if (this.activeIds.includes(v.id)) {
                    this.activeIds.splice(this.activeIds.indexOf(v.id), 1);
                  }
                });
                this.activeIds.push(id);
              }
            }
          }
        }
        let masterId = 0;
        this.activeIds.forEach((v) => {
          if (this.settings.masterarray.includes(v)) {
            masterId = v;
          }
        });
        this.variations.forEach((v) => {
          let q = 0;
          v.attributes.forEach((a) => {
            if (masterId == a.id) {
              q++;
            }
          });
          if (q > 0) {
            v.attributes.forEach((a) => {
              if (this.settings.masterarray.includes(a.id)) {
                if (this.settings.checkstore) {
                  if (v.stock > 0) {
                    xvar.push(v);
                  }
                }
                else {
                  xvar.push(v);
                }
              }
            });
          }
        });
        this.enableIds = [];
        xvar.forEach((v) => {
          v.attributes.forEach((a) => {
            if (!this.enableIds.includes(a.id)) {
              this.enableIds.push(a.id);
            }
          });
        });
        this.settings.masterarray.forEach((m) => {
          if (!this.enableIds.includes(m)) {
            this.enableIds.push(m);
          }
        });
        // Убираем "лишнее"
        for (var attr in this.attributes) {
          if (attr != name && !this.settings.masterarray.includes(this.attributes[attr][0].id)) {
            this.attributes[attr].forEach((v) => {
              let dis = true;
              xvar.forEach((x) => {
                let check = false;
                x.attributes.forEach((a) => {
                  if (a.id == id) {
                    check = true;
                  }
                });
                if (check) {
                  x.attributes.forEach((a) => {
                    if (a.id == v.id) {
                      dis = false;
                    }
                  });
                }
              });
              if (dis) {
                if (this.enableIds.includes(v.id)) {
                  this.enableIds.splice(this.enableIds.indexOf(v.id), 1);
                }
                if (this.activeIds.includes(v.id)) {
                  this.activeIds.splice(this.activeIds.indexOf(v.id), 1);
                }
              }
            });
          }
        }
        if (this.activeIds.length == this.attributeCount) {
          xvar.forEach((v) => {
            let q = 0;
            v.attributes.forEach((a) => {
              if (this.activeIds.includes(a.id)) {
                q++;
              }
            });
            if (q == this.activeIds.length) {
              this.oldPrice = v.oldprice_format;
              this.price = v.price_format;
              this.variationId = v.variation_id;
              if (this.settings.checkstore) {
                if (this.quantity > v.stock) {
                  this.quantity = v.stock;
                }
              }
            }
          });
        }
      },
      choiceOfAttribute(id) {
        // var xactive = this.activeIds;
        var xvar = [];
        this.inCart = false;
        this.variationId = 0;
        if (this.settings.masterarray.includes(id)) {
          this.$store.commit("updateColor", id);
          this.enableIds = [];
          this.activeIds = [];
          this.activeIds.push(id);
        }
        else {
          if (this.activeIds.includes(id)) {
            this.activeIds.splice(this.activeIds.indexOf(id), 1);
          } else {
            if (this.attributeCount > 1) {
              this.activeIds.push(id);
            } else {
              this.activeIds.splice(0, 1);
              this.activeIds.push(id);
            }
          }
        }
        // if (!this.settings.checkstore) {
          for (var attr in this.attributes) {
            let needclear = false;
            this.attributes[attr].forEach((v) => {
              if (id == v.id) {
                needclear = true;
              }
            });
            if (needclear) {
              this.attributes[attr].forEach((v) => {
                if (this.activeIds.includes(v.id)) {
                  this.activeIds.splice(this.activeIds.indexOf(v.id), 1);
                }
              });
              this.activeIds.push(id);
            }
          }
        // }
        if (this.activeIds.length == 0) {
          this.enableIds = [];
          this.variationId = 0;
        }
        else {
          let masterId = 0;
          this.activeIds.forEach((v) => {
            if (this.settings.masterarray.includes(v)) {
              masterId = v;
            }
          });
          this.variations.forEach((v) => {
            let q = 0;
            v.attributes.forEach((a) => {
              if (masterId == a.id) {
                q++;
              }
            });
            if (q > 0) {
              v.attributes.forEach((a) => {
                if (this.settings.masterarray.includes(a.id)) {
                  if (this.settings.checkstore) {
                    if (v.stock > 0) {
                      xvar.push(v);
                    }
                  }
                  else {
                    xvar.push(v);
                  }
                }
              });
            }
          });
          // if (this.settings.checkstore) {
            this.enableIds = [];
            xvar.forEach((v) => {
              v.attributes.forEach((a) => {
                if (!this.enableIds.includes(a.id)) {
                  this.enableIds.push(a.id);
                }
              });
            });
            this.settings.masterarray.forEach((m) => {
              if (!this.enableIds.includes(m)) {
                this.enableIds.push(m);
              }
            });
          // }
          this.variationId = 0;
          if (this.activeIds.length == this.attributeCount) {
            xvar.forEach((v) => {
              let q = 0;
              v.attributes.forEach((a) => {
                if (this.activeIds.includes(a.id)) {
                  q++;
                }
              });
              if (q == this.activeIds.length) {
                this.oldPrice = v.oldprice_format;
                this.price = v.price_format;
                this.variationId = v.variation_id;
              }
              // else {
              //   console.log(v);
              //   let active = this.activeIds;
              //   active.forEach((v) => {
              //     if (v != id && v != masterId) {
              //       this.activeIds.splice(this.activeIds.indexOf(v), 1);
              //       // if (this.enableIds.includes(v)) {
              //       //   this.enableIds.splice(this.enableIds.indexOf(v), 1);
              //       // }
              //     }
              //   });
              // }
            });
          }
        }
      },
    },
    created() {
      this.ready = true;
      if (typeof this.attributes == "object") {
        this.attributeCount = 0;
        for (var attr in this.attributes) {
          this.attributeCount++;
        }
      }
      if (typeof this.variations == "object") {
        this.oldPrice = this.variations[0].oldprice_format;
        this.price = this.variations[0].price_format;
        this.variationId = this.variations[0].variation_id;
        if (this.settings.fullstate) {
          this.variations[0].attributes.forEach((v) => {
            if (this.settings.masterarray.includes(v.id)) {
              this.$store.commit("updateColor", v.id);
              this.choiceOfAttribute(v.id);
            }
          });
          this.variations[0].attributes.forEach((v) => {
            if (!this.settings.masterarray.includes(v.id)) {
              this.choiceOfAttribute(v.id);
            }
          });
        }
      }
    },
  });

  Vue.component("cart", {
    data() {
      return {
        ready: false,
      };
    },
    computed: {
      cart() {
        return this.$store.state.cart;
      },
    },
    methods: {
      productName(item) {
        let t = item.title;
        if (item.uname != '') {
          t += ', ' + item.uname;
        }
        return t;
      },
      initCart() {
        let loadPath = "/api/cart-load";
        let path = drupalSettings.path.currentPath;
        let arg = path.split("/");
        if (arg.length == 3) {
          if (arg[0] == "checkout" && parseInt(arg[1]) > 0) {
            loadPath += "/" + arg[1];
          }
        }
        axios.get(loadPath).then((response) => {
          this.$store.commit("updateCart", response.data);
          if (response.data.quantity > 0) {
            this.ready = true;
          }

        });
      },
      changeQuantity(vid, quantity, step) {
        quantity = !quantity || quantity < step ? step : quantity;
        let stock = this.$store.state.cart.items[vid].stock;
        if (quantity <= stock || stock == 0) {
          axios
            .post("/cart/set-product-quantity", {
              vid: vid,
              quantity: quantity,
            })
            .then((response) => {
              this.$store.commit("updateCart", response.data);
            });
        }
      },
      removeItem(vid) {
        axios.post("/cart/remove-cart-item", { vid: vid }).then((response) => {
          this.ready = false;
          this.initCart();
        });
      },
      numberFormat(number, step, decimals = 2, dec_point = ".", thousands_sep = " ") {
        let s_number =
          Math.abs(parseInt((number = (+number || 0).toFixed(decimals)))) + "";
        let len = s_number.length;
        let tchunk = len > 3 ? len % 3 : 0;
        let ch_first = tchunk ? s_number.substr(0, tchunk) + thousands_sep : "";
        let ch_rest = s_number
          .substr(tchunk)
          .replace(/(\d\d\d)(?=\d)/g, "$1" + thousands_sep);
        let ch_last = decimals
          ? dec_point + (Math.abs(number) - s_number).toFixed(decimals).slice(2)
          : "";
        if (step == 1) {
          ch_last = '';
        }
        return ch_first + ch_rest + ch_last;
      },
      isEmpty(value) {
        if (!!value && value instanceof Array) {
          return value.length < 1;
        }
        if (!!value && typeof value === "object") {
          for (var key in value) {
            if (hasOwnProperty.call(value, key)) {
              return false;
            }
          }
        }
        return !value;
      },
      readQuantity(e, item) {
        let quantity = e.target.innerText;
        quantity = parseInt(quantity.replaceAll(" ", ""));
        if (quantity > 999) {
          quantity = 999;
        } else if (quantity < 1) {
          quantity = 1;
        }
        this.changeQuantity(item.id, quantity, item.qstep);
      },
    },
    created() {
      this.initCart();
    },
  });

  String.prototype.replaceAll = function (search, replacement) {
    return this.split(search).join(replacement);
  };
})();
